==> apache-inlong-1.4.0-src.tar.gz: apache-inlong-1.4.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/VarBinaryFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import org.junit.Test;

import java.nio.charset.StandardCharsets;
import java.util.Collection;
import java.util.Collections;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertEquals;

public class VarBinaryFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        return Collections.singletonList(VarBinaryFormatInfo.INSTANCE);
    }

    @Test
    public void testSerialize() throws Exception {
        assertEquals(
                "testString",
                VarBinaryFormatInfo.INSTANCE.serialize("testString".getBytes(StandardCharsets.UTF_8))
        );
    }

    @Test
    public void testDeserialize() throws Exception {
        assertArrayEquals(
                "testString".getBytes(StandardCharsets.UTF_8),
                VarBinaryFormatInfo.INSTANCE.deserialize("testString")
        );
    }

}

==> apache-inlong-1.11.0-src.tar.gz: apache-inlong-1.11.0/inlong-sort/sort-formats/format-common/src/test/java/org/apache/inlong/sort/formats/common/VarBinaryFormatInfoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.inlong.sort.formats.common;

import org.junit.Test;

import java.nio.charset.StandardCharsets;
import java.util.Collection;
import java.util.Collections;

import static org.junit.Assert.assertArrayEquals;
import static org.junit.Assert.assertEquals;

public class VarBinaryFormatInfoTest extends FormatInfoTestBase {

    @Override
    Collection<FormatInfo> createFormatInfos() {
        return Collections.singletonList(VarBinaryFormatInfo.INSTANCE);
    }

    @Test
    public void testSerialize() throws Exception {
        assertEquals(
                "testString",
                VarBinaryFormatInfo.INSTANCE.serialize("testString".getBytes(StandardCharsets.UTF_8)));
    }

    @Test
    public void testDeserialize() throws Exception {
        assertArrayEquals(
                "testString".getBytes(StandardCharsets.UTF_8),
                VarBinaryFormatInfo.INSTANCE.deserialize("testString"));
    }

}
